@@ -4,8 +4,7 @@
 #define __GUILE_SDL_H
 
 /*
- * Copyright (C) 2003, 2004, 2005, 2007, 2008,
- *   2009, 2011, 2013 Thien-Thi Nguyen
+ * Copyright (C) 2003-2005, 2007-2009, 2011, 2013, 2015 Thien-Thi Nguyen
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -17,10 +16,8 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA  02110-1301  USA
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 
@@ -316,7 +313,6 @@ struct obtw
   SCM video_flags;
   /* Flags used in various sdl{surface,video}.c funcs.  */
 
-  SCM event_state_enum;
   SCM updn_enum;
   /* Used in various sdl{event,joystick}.c funcs.  */
 
