@@ -1,7 +1,6 @@
 /* sdlmixer.c --- SDL_mixer for Guile
  *
- * Copyright (C) 2003, 2004, 2005, 2007, 2008,
- *   2009, 2011, 2013 Thien-Thi Nguyen
+ * Copyright (C) 2003-2005, 2007-2009, 2011, 2013, 2015 Thien-Thi Nguyen
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -13,10 +12,8 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA  02110-1301  USA
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #define GUILE_SDL_OPTIONAL_MODULE  1
@@ -136,36 +133,6 @@ allocated channels).  */)
 }
 
 
-DECLARE_SIMPLE_SYM (freq);
-DECLARE_SIMPLE_SYM (format);
-DECLARE_SIMPLE_SYM (channels);
-
-PRIMPROC
-(mix_query_spec, "query-spec", 0, 0, 0,
- (void),
- doc: /***********
-NB: This procedure is obsoleted by @code{device-ffc}
-and @strong{will be removed} after 2013-12-31.
-
-Return audio device parameters as an alist, or @code{#f}
-if the audio has not yet been opened.
-Keys are @code{freq} (frequency), @code{format},
-and @code{channels} (the number of allocated channels).  */)
-{
-#define FUNC_NAME s_mix_query_spec
-  int freq, channels;
-  Uint16 format;
-
-  if (! Mix_QuerySpec (&freq, &format, &channels))
-    return BOOL_FALSE;
-
-  return LIST3 (CONS (SYM (freq), NUM_LONG (freq)),
-                CONS (SYM (format), NUM_LONG (format)),
-                CONS (SYM (channels), NUM_LONG (channels)));
-#undef FUNC_NAME
-}
-
-
 PRIMPROC
 (mix_load_music, "load-music", 1, 0, 0,
  (SCM filename),
