@@ -1,6 +1,6 @@
 ;;; event.scm --- simple event test
 
-;; Copyright (C) 2003, 2004, 2005, 2008, 2009, 2011, 2013 Thien-Thi Nguyen
+;; Copyright (C) 2003-2005, 2008, 2009, 2011, 2013, 2015 Thien-Thi Nguyen
 ;;
 ;; This program is free software; you can redistribute it and/or
 ;; modify it under the terms of the GNU General Public License as
@@ -12,28 +12,19 @@
 ;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ;; GNU General Public License for more details.
 ;;
-;; You should have received a copy of the GNU General Public
-;; License along with this program; if not, write to the Free
-;; Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-;; Boston, MA  02110-1301  USA
+;; You should have received a copy of the GNU General Public License
+;; along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 (use-modules ((srfi srfi-1) #:select (car+cdr))
              ((srfi srfi-11) #:select (let-values))
              ((srfi srfi-13) #:select (string-suffix?)))
 (use-modules ((sdl sdl) #:prefix SDL:)
              ((sdl gfx) #:prefix GFX:))
+(use-modules ((sdl misc-utils) #:select (ignore-all-event-types-except)))
 
 (define (check-joystick-maybe)
   (info "joystick polling => ~S"
-        (let* ((ans (SDL:joystick-polling))
-               (raw (SDL:joystick-event-state 'SDL_QUERY))
-               (old (case raw
-                      ((SDL_ENABLE) #t)
-                      ((SDL_IGNORE) #f)
-                      (else (error "WTF:" raw)))))
-          (or (eq? ans old)
-              (error "discrepency:" (list 'ans: ans 'old: old)))
-          ans))
+        (SDL:joystick-polling))
   (or (SDL:joystick-polling)
       (SDL:joystick-polling #t)
       (error "could not enable joystick polling"))
@@ -163,7 +154,7 @@
 ;; mod and mouse state
 (SDL:set-mod-state '(L-alt R-alt))
 (info "(jammed) mod state => ~S" (SDL:get-mod-state))
-(info "(actual) mouse state => ~S" (SDL:get-mouse-state #t))
+(info "(actual) mouse bxy => ~S" (call-with-values SDL:mouse-bxy list))
 
 (define (fake type . rest)
   (info "(fake)\t~A" type)
@@ -292,21 +283,9 @@
       (let-values (((buttons x y) (SDL:mouse-bxy #t)))
         (draw-relative-rectangle! x y)
         (display-centered/next-next-line "~A ~A ~A" buttons x y)
-        (let* ((alist (SDL:get-mouse-relative-state #t))
-               (gmrs-state (assq-ref alist 'state))
-               (gmrs-x     (assq-ref alist 'x))
-               (gmrs-y     (assq-ref alist 'y)))
-          (or (null? buttons)
-              (SDL:button? buttons)
-              (error "mouse-bxy and button? do not agree!"))
-          (or (equal? buttons gmrs-state)
-              (error "mouse-bxy and get-mouse-relative-state disagree:"
-                     (list 'bxy: buttons
-                           'rel: gmrs-state)))
-          (or (zero? gmrs-x)
-              (error "get-mouse-relative-state x non-zero:" gmrs-x))
-          (or (zero? gmrs-y)
-              (error "get-mouse-relative-state y non-zero:" gmrs-y))))
+        (or (null? buttons)
+            (SDL:button? buttons)
+            (error "mouse-bxy and button? do not agree!")))
       (case event-type
         ((key-down key-up)
          (let ((sym (SDL:event:key:keysym:sym e))
@@ -396,23 +375,11 @@
             (display-centered
              "~A . ~A"
              (nice-type type)
-             (let* ((ans (if (SDL:event-type-handling type)
-                             'yes
-                             'no))
-                    (raw (SDL:event-state type 'SDL_QUERY))
-                    (old (case raw
-                           ((SDL_ENABLE) 'yes)
-                           ((SDL_IGNORE) 'no)
-                           (else (error "WTF:" raw)))))
-               (or (eq? ans old)
-                   (error "discrepency:" (list 'ans: ans 'old: old)))
-               ans)))
+             (if (SDL:event-type-handling type)
+                 'yes
+                 'no)))
           (map car (SDL:kotk 'event-type)))
 
-;; display an explanatory message
-((display-centered-w/height-proc (- (SDL:rect:h test-rect) height 5))
- "(Press ESC to Quit, SPC to Cycle Filter)")
-
 ;; enable keyboard repeat
 (SDL:enable-key-repeat 250 6)
 
@@ -489,13 +456,11 @@
   ;; resize
   (fake 'video-resize
         SDL:event:resize:set-h! 420
-        SDL:event:resize:set-w! 420)
-  ;; bail if not interactive
-  (or *interactive* (fake-key-down/up '() 'escape)))
+        SDL:event:resize:set-w! 420))
 
 ;; queue interaction
 (SDL:pump-events)
-(let ((count (SDL:peep-events #f 10 'SDL_PEEKEVENT '())))
+(let ((count (SDL:evqueue-peek 99 #f)))
   (or (zero? count)
       (error "pending events not properly masked:"
              (cons 'count: count))))
@@ -512,9 +477,21 @@
     (info "~A events successfully re-enqueud" back)
     (or (= count back)
         (error "evqueue-add rv:" back))))
+(scroll-up!)
+
+;; fleeting ignorance
+(let ((blurb! (display-centered-w/height-proc
+               (- (SDL:rect:h test-rect) height 5))))
+  (blurb! "WAIT A (QUARTER) SECOND!")
+  (ignore-all-event-types-except)
+  (SDL:delay 250)
+  (ignore-all-event-types-except #f)
+  (or *interactive*
+      ;; arrange to bail
+      (fake-key-down/up '() 'escape))
+  (blurb! "(Press ESC to Quit, SPC to Cycle Filter)"))
 
 ;; main loop
-(scroll-up!)
 (input-loop (SDL:make-event 0))
 
 ;; quit SDL
